@@ -9,7 +9,8 @@
 #' @param model object - a model to be explained
 #' @param data data.frame or matrix - data that was used for fitting. If not provided then will be extracted from the model
 #' @param y numeric vector with outputs / scores. Currently used only by \code{variable_dropout()} explainer.
-#' @param predict.function function that takes two arguments: model and new data and returns numeric vector with predictions
+#' @param predict_function function that takes two arguments: model and new data and returns numeric vector with predictions
+#' @param link function - a transformation/link function that shall be applied to raw model predictions
 #' @param ... other parameters
 #' @param label character - the name of the model. By default it's extracted from the 'class' attribute of the model
 #'
@@ -20,7 +21,7 @@
 #' \itemize{
 #' \item \code{model} the explained model
 #' \item \code{data} the dataset used for training
-#' \item \code{predict.function} function that may be used for model predictions, shall return a single numerical value for each observation.
+#' \item \code{predict_function} function that may be used for model predictions, shall return a single numerical value for each observation.
 #' \item \code{class} class/classes of a model
 #' \item \code{label} label, by default it's the last value from the \code{class} vector, but may be set to any character.
 #' }
@@ -43,7 +44,7 @@
 #' wine_rf_explainer4
 #' }
 #'
-explain <- function(model, data = NULL, y = NULL, predict.function = yhat, label = tail(class(model), 1)) {
+explain <- function(model, data = NULL, y = NULL, predict_function = yhat, link = I, ..., label = tail(class(model), 1)) {
   if (is.null(data)) {
     possible_data <- try(model.frame(model), silent = TRUE)
     if (class(possible_data) != "try-error") {
@@ -54,11 +55,19 @@ explain <- function(model, data = NULL, y = NULL, predict.function = yhat, label
   explainer <- list(model = model,
                     data = data,
                     y = y,
-                    predict.function = predict.function,
+                    predict_function = predict_function,
+                    link = link,
                     class = class(model),
                     label = label)
+  explainer <- c(explainer, list(...))
   class(explainer) <- "explainer"
   explainer
 }
 
-yhat <- function(X.model, newdata) as.numeric(predict(X.model, newdata))
+yhat <- function(X.model, newdata, ...) {
+  if ("lm" %in% class(X.model)) {
+    stats::predict(X.model, newdata, ...)
+  } else {
+    as.numeric(stats::predict(X.model, newdata, ...))
+  }
+}
